@@ -24,7 +24,7 @@
 #include <memory>
 #include <string>
 
-#include "src/core/lib/config/config_vars.h"
+#include "src/core/config/config_vars.h"
 #include "src/cpp/ext/proto_server_reflection.h"
 
 namespace grpc {
