@@ -16,20 +16,20 @@
 //
 //
 
-#include <memory>
-
-#include "absl/log/check.h"
-
 #include <grpc/grpc.h>
 #include <grpc/grpc_security.h>
 #include <grpcpp/security/server_credentials.h>
 
+#include <memory>
+
+#include "src/core/util/grpc_check.h"
+
 namespace grpc {
 
 std::shared_ptr<ServerCredentials> XdsServerCredentials(
     const std::shared_ptr<ServerCredentials>& fallback_credentials) {
-  CHECK_NE(fallback_credentials, nullptr);
-  CHECK_NE(fallback_credentials->c_creds_, nullptr);
+  GRPC_CHECK_NE(fallback_credentials, nullptr);
+  GRPC_CHECK_NE(fallback_credentials->c_creds_, nullptr);
   return std::shared_ptr<ServerCredentials>(new ServerCredentials(
       grpc_xds_server_credentials_create(fallback_credentials->c_creds_)));
 }
