@@ -15,6 +15,7 @@
 #ifndef GRPC_PYTHON_OBSERVABILITY_CONSTANTS_H
 #define GRPC_PYTHON_OBSERVABILITY_CONSTANTS_H
 
+#include <set>
 #include <string>
 
 namespace grpc_observability {
@@ -25,6 +26,7 @@ const std::string kClientStatus = "grpc.status";
 const std::string kServerMethod = "grpc.method";
 const std::string kServerStatus = "grpc.status";
 const std::string kRegisteredMethod = "registerMethod";
+const std::string kXEnvoyPeerMetadata = "XEnvoyPeerMetadata";
 
 typedef enum { kMeasurementDouble = 0, kMeasurementInt } MeasurementType;
 
@@ -53,6 +55,8 @@ typedef enum {
   kRpcServerStartedRpcsMeasureName
 } MetricsName;
 
+const std::set<std::string> MetadataExchangeKeyNames = {kXEnvoyPeerMetadata};
+
 }  // namespace grpc_observability
 
 #endif  // GRPC_PYTHON_OBSERVABILITY_CONSTANTS_H
