@@ -18,13 +18,11 @@
 
 #include "test/core/bad_ssl/server_common.h"
 
+#include <grpc/support/time.h>
 #include <signal.h>
 
-#include "absl/log/check.h"
 #include "absl/log/log.h"
-
-#include <grpc/support/time.h>
-
+#include "src/core/util/grpc_check.h"
 #include "test/core/test_util/cmdline.h"
 #include "test/core/test_util/test_config.h"
 
@@ -44,7 +42,7 @@ const char* bad_ssl_addr(int argc, char** argv) {
   gpr_cmdline_add_string(cl, "bind", "Bind host:port", &addr);
   gpr_cmdline_parse(cl, argc, argv);
   gpr_cmdline_destroy(cl);
-  CHECK(addr);
+  GRPC_CHECK(addr);
   return addr;
 }
 
@@ -69,7 +67,7 @@ void bad_ssl_run(grpc_server* server) {
   error = grpc_server_request_call(server, &s, &call_details,
                                    &request_metadata_recv, cq, cq,
                                    reinterpret_cast<void*>(1));
-  CHECK_EQ(error, GRPC_CALL_OK);
+  GRPC_CHECK_EQ(error, GRPC_CALL_OK);
 
   signal(SIGINT, sigint_handler);
   while (!shutdown_finished) {
@@ -77,10 +75,10 @@ void bad_ssl_run(grpc_server* server) {
       LOG(INFO) << "Shutting down due to SIGINT";
       shutdown_cq = grpc_completion_queue_create_for_pluck(nullptr);
       grpc_server_shutdown_and_notify(server, shutdown_cq, nullptr);
-      CHECK(grpc_completion_queue_pluck(shutdown_cq, nullptr,
-                                        grpc_timeout_seconds_to_deadline(5),
-                                        nullptr)
-                .type == GRPC_OP_COMPLETE);
+      GRPC_CHECK(grpc_completion_queue_pluck(
+                     shutdown_cq, nullptr, grpc_timeout_seconds_to_deadline(5),
+                     nullptr)
+                     .type == GRPC_OP_COMPLETE);
       grpc_completion_queue_destroy(shutdown_cq);
       grpc_completion_queue_shutdown(cq);
       shutdown_started = 1;
@@ -92,11 +90,11 @@ void bad_ssl_run(grpc_server* server) {
         nullptr);
     switch (ev.type) {
       case GRPC_OP_COMPLETE:
-        CHECK(ev.tag == (void*)1);
-        CHECK_EQ(ev.success, 0);
+        GRPC_CHECK(ev.tag == (void*)1);
+        GRPC_CHECK_EQ(ev.success, 0);
         break;
       case GRPC_QUEUE_SHUTDOWN:
-        CHECK(shutdown_started);
+        GRPC_CHECK(shutdown_started);
         shutdown_finished = 1;
         break;
       case GRPC_QUEUE_TIMEOUT:
@@ -104,7 +102,7 @@ void bad_ssl_run(grpc_server* server) {
     }
   }
 
-  CHECK_EQ(s, nullptr);
+  GRPC_CHECK_EQ(s, nullptr);
   grpc_call_details_destroy(&call_details);
   grpc_metadata_array_destroy(&request_metadata_recv);
 }
