@@ -29,50 +29,27 @@
 #include <stdint.h>
 #include <string.h>
 
-#include <algorithm>
-#include <functional>
 #include <memory>
 #include <string>
-#include <utility>
 #include <vector>
 
-#include "absl/log/check.h"
 #include "absl/log/log.h"
 #include "absl/status/status.h"
 #include "absl/status/statusor.h"
 #include "absl/strings/str_cat.h"
 #include "absl/strings/string_view.h"
 #include "src/core/lib/channel/channel_args.h"
-#include "src/core/lib/event_engine/default_event_engine.h"
-#include "src/core/lib/experiments/experiments.h"
-#include "src/core/lib/iomgr/closure.h"
-#include "src/core/lib/iomgr/error.h"
-#include "src/core/lib/iomgr/exec_ctx.h"
-#include "src/core/lib/iomgr/iomgr_fwd.h"
-#include "src/core/lib/iomgr/resolve_address.h"
-#include "src/core/lib/iomgr/resolve_address_impl.h"
-#include "src/core/lib/iomgr/resolved_address.h"
 #include "src/core/lib/iomgr/sockaddr.h"
 #include "src/core/lib/iomgr/socket_utils.h"
-#include "src/core/resolver/dns/c_ares/grpc_ares_wrapper.h"
-#include "src/core/resolver/endpoint_addresses.h"
-#include "src/core/util/debug_location.h"
-#include "src/core/util/time.h"
+#include "src/core/util/grpc_check.h"
 #include "test/core/end2end/cq_verifier.h"
+#include "test/core/event_engine/util/delegating_event_engine.h"
 #include "test/core/test_util/port.h"
 #include "test/core/test_util/test_config.h"
 
 static gpr_mu g_mu;
 static int g_resolve_port = -1;
 
-static grpc_ares_request* (*iomgr_dns_lookup_ares)(
-    const char* dns_server, const char* addr, const char* default_port,
-    grpc_pollset_set* interested_parties, grpc_closure* on_done,
-    std::unique_ptr<grpc_core::EndpointAddressesList>* addresses,
-    int query_timeout_ms);
-
-static void (*iomgr_cancel_ares_request)(grpc_ares_request* request);
-
 static void set_resolve_port(int port) {
   gpr_mu_lock(&g_mu);
   g_resolve_port = port;
@@ -81,139 +58,77 @@ static void set_resolve_port(int port) {
 
 namespace {
 
-class TestDNSResolver : public grpc_core::DNSResolver {
+using grpc_event_engine::experimental::EventEngine;
+
+class TestDNSResolver : public EventEngine::DNSResolver {
  public:
-  explicit TestDNSResolver(
-      std::shared_ptr<grpc_core::DNSResolver> default_resolver)
-      : default_resolver_(std::move(default_resolver)),
-        engine_(grpc_event_engine::experimental::GetDefaultEventEngine()) {}
-  TaskHandle LookupHostname(
-      std::function<void(absl::StatusOr<std::vector<grpc_resolved_address>>)>
-          on_resolved,
-      absl::string_view name, absl::string_view default_port,
-      grpc_core::Duration timeout, grpc_pollset_set* interested_parties,
-      absl::string_view name_server) override {
+  explicit TestDNSResolver(std::shared_ptr<EventEngine> engine)
+      : engine_(std::move(engine)),
+        default_resolver_(engine_->GetDNSResolver(
+            EventEngine::DNSResolver::ResolverOptions())) {}
+
+  void LookupHostname(LookupHostnameCallback on_resolve, absl::string_view name,
+                      absl::string_view default_port) override {
+    GRPC_CHECK(default_resolver_.ok());
     if (name != "test") {
-      return default_resolver_->LookupHostname(std::move(on_resolved), name,
-                                               default_port, timeout,
-                                               interested_parties, name_server);
+      return (*default_resolver_)
+          ->LookupHostname(std::move(on_resolve), name, default_port);
     }
-    MakeDNSRequest(std::move(on_resolved));
-    return kNullHandle;
-  }
-
-  absl::StatusOr<std::vector<grpc_resolved_address>> LookupHostnameBlocking(
-      absl::string_view name, absl::string_view default_port) override {
-    return default_resolver_->LookupHostnameBlocking(name, default_port);
-  }
-
-  TaskHandle LookupSRV(
-      std::function<void(absl::StatusOr<std::vector<grpc_resolved_address>>)>
-          on_resolved,
-      absl::string_view /* name */, grpc_core::Duration /* timeout */,
-      grpc_pollset_set* /* interested_parties */,
-      absl::string_view /* name_server */) override {
-    engine_->Run([on_resolved] {
-      grpc_core::ApplicationCallbackExecCtx app_exec_ctx;
-      grpc_core::ExecCtx exec_ctx;
-      on_resolved(absl::UnimplementedError(
-          "The Testing DNS resolver does not support looking up SRV records"));
-    });
-    return {-1, -1};
-  };
-
-  TaskHandle LookupTXT(
-      std::function<void(absl::StatusOr<std::string>)> on_resolved,
-      absl::string_view /* name */, grpc_core::Duration /* timeout */,
-      grpc_pollset_set* /* interested_parties */,
-      absl::string_view /* name_server */) override {
-    // Not supported
-    engine_->Run([on_resolved] {
-      grpc_core::ApplicationCallbackExecCtx app_exec_ctx;
-      grpc_core::ExecCtx exec_ctx;
-      on_resolved(absl::UnimplementedError(
-          "The Testing DNS resolver does not support looking up TXT records"));
-    });
-    return {-1, -1};
-  };
-
-  bool Cancel(TaskHandle /*handle*/) override { return false; }
-
- private:
-  void MakeDNSRequest(
-      std::function<void(absl::StatusOr<std::vector<grpc_resolved_address>>)>
-          on_done) {
     gpr_mu_lock(&g_mu);
     if (g_resolve_port < 0) {
       gpr_mu_unlock(&g_mu);
-      new grpc_core::DNSCallbackExecCtxScheduler(
-          std::move(on_done), absl::UnknownError("Forced Failure"));
+      engine_->Run([on_resolve = std::move(on_resolve)]() mutable {
+        on_resolve(absl::UnknownError("Forced Failure"));
+      });
     } else {
-      std::vector<grpc_resolved_address> addrs;
-      grpc_resolved_address addr;
-      grpc_sockaddr_in* sa = reinterpret_cast<grpc_sockaddr_in*>(&addr);
-      sa->sin_family = GRPC_AF_INET;
-      sa->sin_addr.s_addr = 0x100007f;
-      sa->sin_port = grpc_htons(static_cast<uint16_t>(g_resolve_port));
-      addr.len = static_cast<socklen_t>(sizeof(*sa));
-      addrs.push_back(addr);
+      std::vector<EventEngine::ResolvedAddress> addrs;
+      struct sockaddr_in in;
+      memset(&in, 0, sizeof(struct sockaddr_in));
+      in.sin_family = GRPC_AF_INET;
+      in.sin_addr.s_addr = 0x100007f;
+      in.sin_port = grpc_htons(static_cast<uint16_t>(g_resolve_port));
+      addrs.emplace_back(reinterpret_cast<const sockaddr*>(&in),
+                         sizeof(struct sockaddr_in));
       gpr_mu_unlock(&g_mu);
-      new grpc_core::DNSCallbackExecCtxScheduler(std::move(on_done),
-                                                 std::move(addrs));
+      engine_->Run([on_resolve = std::move(on_resolve),
+                    addrs = std::move(addrs)]() mutable {
+        on_resolve(std::move(addrs));
+      });
     }
   }
-  std::shared_ptr<grpc_core::DNSResolver> default_resolver_;
-  std::shared_ptr<grpc_event_engine::experimental::EventEngine> engine_;
+  void LookupSRV(LookupSRVCallback on_resolve,
+                 absl::string_view name) override {
+    GRPC_CHECK(default_resolver_.ok());
+    return (*default_resolver_)->LookupSRV(std::move(on_resolve), name);
+  }
+  void LookupTXT(LookupTXTCallback on_resolve,
+                 absl::string_view name) override {
+    GRPC_CHECK(default_resolver_.ok());
+    return (*default_resolver_)->LookupTXT(std::move(on_resolve), name);
+  }
+
+ private:
+  std::shared_ptr<EventEngine> engine_;
+  absl::StatusOr<std::unique_ptr<EventEngine::DNSResolver>> default_resolver_;
+};
+
+class TestEventEngine
+    : public grpc_event_engine::experimental::DelegatingEventEngine {
+ public:
+  explicit TestEventEngine(std::shared_ptr<EventEngine> default_event_engine)
+      : DelegatingEventEngine(std::move(default_event_engine)) {}
+
+  ~TestEventEngine() override = default;
+
+  absl::StatusOr<std::unique_ptr<DNSResolver>> GetDNSResolver(
+      const DNSResolver::ResolverOptions& options) override {
+    return std::make_unique<TestDNSResolver>(wrapped_engine());
+  }
 };
 
 }  // namespace
 
-static grpc_ares_request* my_dns_lookup_ares(
-    const char* dns_server, const char* addr, const char* default_port,
-    grpc_pollset_set* interested_parties, grpc_closure* on_done,
-    std::unique_ptr<grpc_core::EndpointAddressesList>* addresses,
-    int query_timeout_ms) {
-  if (0 != strcmp(addr, "test")) {
-    // A records should suffice
-    return iomgr_dns_lookup_ares(dns_server, addr, default_port,
-                                 interested_parties, on_done, addresses,
-                                 query_timeout_ms);
-  }
-
-  grpc_error_handle error;
-  gpr_mu_lock(&g_mu);
-  if (g_resolve_port < 0) {
-    gpr_mu_unlock(&g_mu);
-    error = GRPC_ERROR_CREATE("Forced Failure");
-  } else {
-    *addresses = std::make_unique<grpc_core::EndpointAddressesList>();
-    grpc_resolved_address address;
-    memset(&address, 0, sizeof(address));
-    auto* sa = reinterpret_cast<grpc_sockaddr_in*>(&address.addr);
-    sa->sin_family = GRPC_AF_INET;
-    sa->sin_addr.s_addr = 0x100007f;
-    sa->sin_port = grpc_htons(static_cast<uint16_t>(g_resolve_port));
-    address.len = sizeof(grpc_sockaddr_in);
-    (*addresses)->emplace_back(address, grpc_core::ChannelArgs());
-    gpr_mu_unlock(&g_mu);
-  }
-  grpc_core::ExecCtx::Run(DEBUG_LOCATION, on_done, error);
-  return nullptr;
-}
-
-static void my_cancel_ares_request(grpc_ares_request* request) {
-  if (request != nullptr) {
-    iomgr_cancel_ares_request(request);
-  }
-}
-
 int main(int argc, char** argv) {
-  // TODO(yijiem): rewrite this test with a custom EventEngine DNS Resolver
-  if (grpc_core::IsEventEngineDnsEnabled()) {
-    LOG(ERROR) << "Skipping iomgr-specific DNS test because EventEngine DNS is "
-                  "enabled";
-    return 0;
-  }
   grpc_completion_queue* cq;
   grpc_op ops[6];
   grpc_op* op;
@@ -222,12 +137,9 @@ int main(int argc, char** argv) {
 
   gpr_mu_init(&g_mu);
   grpc_init();
-  grpc_core::ResetDNSResolver(
-      std::make_unique<TestDNSResolver>(grpc_core::GetDNSResolver()));
-  iomgr_dns_lookup_ares = grpc_dns_lookup_hostname_ares;
-  iomgr_cancel_ares_request = grpc_cancel_ares_request;
-  grpc_dns_lookup_hostname_ares = my_dns_lookup_ares;
-  grpc_cancel_ares_request = my_cancel_ares_request;
+  auto test_event_engine = std::make_shared<TestEventEngine>(
+      grpc_event_engine::experimental::GetDefaultEventEngine());
+  grpc_event_engine::experimental::SetDefaultEventEngine(test_event_engine);
 
   int was_cancelled1;
   int was_cancelled2;
@@ -265,7 +177,7 @@ int main(int argc, char** argv) {
           .Set(GRPC_ARG_MAX_RECONNECT_BACKOFF_MS, 1000)
           .Set(GRPC_ARG_MIN_RECONNECT_BACKOFF_MS, 5000)
           // When this test brings down server1 and then brings up server2,
-          // the targetted server port number changes, and the client channel
+          // the targeted server port number changes, and the client channel
           // needs to re-resolve to pick this up. This test requires that
           // happen within 10 seconds, but gRPC's DNS resolvers rate limit
           // resolution attempts to at most once every 30 seconds by default.
@@ -291,9 +203,9 @@ int main(int argc, char** argv) {
   op->flags = GRPC_INITIAL_METADATA_WAIT_FOR_READY;
   op->reserved = nullptr;
   op++;
-  CHECK_EQ(GRPC_CALL_OK,
-           grpc_call_start_batch(call1, ops, (size_t)(op - ops),
-                                 grpc_core::CqVerifier::tag(0x101), nullptr));
+  GRPC_CHECK_EQ(GRPC_CALL_OK, grpc_call_start_batch(
+                                  call1, ops, (size_t)(op - ops),
+                                  grpc_core::CqVerifier::tag(0x101), nullptr));
   // and receive status to probe termination
   memset(ops, 0, sizeof(ops));
   op = ops;
@@ -304,9 +216,9 @@ int main(int argc, char** argv) {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  CHECK_EQ(GRPC_CALL_OK,
-           grpc_call_start_batch(call1, ops, (size_t)(op - ops),
-                                 grpc_core::CqVerifier::tag(0x102), nullptr));
+  GRPC_CHECK_EQ(GRPC_CALL_OK, grpc_call_start_batch(
+                                  call1, ops, (size_t)(op - ops),
+                                  grpc_core::CqVerifier::tag(0x102), nullptr));
 
   // bring a server up on the first port
   grpc_server* server1 = grpc_server_create(nullptr, nullptr);
@@ -320,10 +232,10 @@ int main(int argc, char** argv) {
 
   // request a call to the server
   grpc_call* server_call1;
-  CHECK_EQ(GRPC_CALL_OK,
-           grpc_server_request_call(server1, &server_call1, &request_details1,
-                                    &request_metadata1, cq, cq,
-                                    grpc_core::CqVerifier::tag(0x301)));
+  GRPC_CHECK_EQ(GRPC_CALL_OK, grpc_server_request_call(
+                                  server1, &server_call1, &request_details1,
+                                  &request_metadata1, cq, cq,
+                                  grpc_core::CqVerifier::tag(0x301)));
 
   set_resolve_port(port1);
 
@@ -332,7 +244,8 @@ int main(int argc, char** argv) {
   cqv.Expect(grpc_core::CqVerifier::tag(0x301), true);
   cqv.Verify();
 
-  CHECK(GRPC_CHANNEL_READY == grpc_channel_check_connectivity_state(chan, 0));
+  GRPC_CHECK(GRPC_CHANNEL_READY ==
+             grpc_channel_check_connectivity_state(chan, 0));
   grpc_channel_watch_connectivity_state(chan, GRPC_CHANNEL_READY,
                                         gpr_inf_future(GPR_CLOCK_REALTIME), cq,
                                         grpc_core::CqVerifier::tag(0x9999));
@@ -344,9 +257,9 @@ int main(int argc, char** argv) {
   op->data.recv_close_on_server.cancelled = &was_cancelled1;
   op->flags = 0;
   op++;
-  CHECK_EQ(GRPC_CALL_OK,
-           grpc_call_start_batch(server_call1, ops, (size_t)(op - ops),
-                                 grpc_core::CqVerifier::tag(0x302), nullptr));
+  GRPC_CHECK_EQ(GRPC_CALL_OK, grpc_call_start_batch(
+                                  server_call1, ops, (size_t)(op - ops),
+                                  grpc_core::CqVerifier::tag(0x302), nullptr));
 
   // shutdown first server:
   // we should see a connectivity change and then nothing
@@ -370,9 +283,9 @@ int main(int argc, char** argv) {
   op->flags = GRPC_INITIAL_METADATA_WAIT_FOR_READY;
   op->reserved = nullptr;
   op++;
-  CHECK_EQ(GRPC_CALL_OK,
-           grpc_call_start_batch(call2, ops, (size_t)(op - ops),
-                                 grpc_core::CqVerifier::tag(0x201), nullptr));
+  GRPC_CHECK_EQ(GRPC_CALL_OK, grpc_call_start_batch(
+                                  call2, ops, (size_t)(op - ops),
+                                  grpc_core::CqVerifier::tag(0x201), nullptr));
   // and receive status to probe termination
   memset(ops, 0, sizeof(ops));
   op = ops;
@@ -383,9 +296,9 @@ int main(int argc, char** argv) {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  CHECK_EQ(GRPC_CALL_OK,
-           grpc_call_start_batch(call2, ops, (size_t)(op - ops),
-                                 grpc_core::CqVerifier::tag(0x202), nullptr));
+  GRPC_CHECK_EQ(GRPC_CALL_OK, grpc_call_start_batch(
+                                  call2, ops, (size_t)(op - ops),
+                                  grpc_core::CqVerifier::tag(0x202), nullptr));
 
   // and bring up second server
   set_resolve_port(port2);
@@ -400,10 +313,10 @@ int main(int argc, char** argv) {
 
   // request a call to the server
   grpc_call* server_call2;
-  CHECK_EQ(GRPC_CALL_OK,
-           grpc_server_request_call(server2, &server_call2, &request_details2,
-                                    &request_metadata2, cq, cq,
-                                    grpc_core::CqVerifier::tag(0x401)));
+  GRPC_CHECK_EQ(GRPC_CALL_OK, grpc_server_request_call(
+                                  server2, &server_call2, &request_details2,
+                                  &request_metadata2, cq, cq,
+                                  grpc_core::CqVerifier::tag(0x401)));
 
   // second call should now start
   cqv.Expect(grpc_core::CqVerifier::tag(0x201), true);
@@ -417,9 +330,9 @@ int main(int argc, char** argv) {
   op->data.recv_close_on_server.cancelled = &was_cancelled2;
   op->flags = 0;
   op++;
-  CHECK_EQ(GRPC_CALL_OK,
-           grpc_call_start_batch(server_call2, ops, (size_t)(op - ops),
-                                 grpc_core::CqVerifier::tag(0x402), nullptr));
+  GRPC_CHECK_EQ(GRPC_CALL_OK, grpc_call_start_batch(
+                                  server_call2, ops, (size_t)(op - ops),
+                                  grpc_core::CqVerifier::tag(0x402), nullptr));
 
   // shutdown second server: we should see nothing
   grpc_server_shutdown_and_notify(server2, cq,
@@ -457,8 +370,11 @@ int main(int argc, char** argv) {
 
   grpc_completion_queue_destroy(cq);
 
+  test_event_engine.reset();
+  grpc_event_engine::experimental::ShutdownDefaultEventEngine();
+
   grpc_shutdown();
   gpr_mu_destroy(&g_mu);
 
   return 0;
-}
+}  // namespace
