@@ -23,7 +23,6 @@
 #include <utility>
 #include <vector>
 
-#include "absl/log/check.h"
 #include "absl/status/status.h"
 #include "absl/status/statusor.h"
 #include "absl/strings/string_view.h"
@@ -32,6 +31,7 @@
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/load_balancing/lb_policy.h"
 #include "src/core/load_balancing/lb_policy_factory.h"
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/json/json.h"
 #include "src/core/util/orphanable.h"
 #include "src/core/util/ref_counted_ptr.h"
@@ -102,20 +102,20 @@ void RegisterDropPolicy(CoreConfiguration::Builder* builder) {
 // - first attempt returns UNAVAILABLE due to LB drop but does not retry
 CORE_END2END_TEST(RetryTests, RetryLbDrop) {
   SKIP_IF_V3();  // Not working yet
-  SKIP_IF_CORE_CONFIGURATION_RESET_DISABLED();
-  CoreConfiguration::RegisterBuilder([](CoreConfiguration::Builder* builder) {
-    RegisterTestPickArgsLoadBalancingPolicy(
-        builder,
-        [](const PickArgsSeen& pick_args) {
-          CHECK_NE(g_pick_args_vector, nullptr);
-          g_pick_args_vector->push_back(pick_args);
-        },
-        kDropPolicyName);
-  });
-  CoreConfiguration::RegisterBuilder(RegisterDropPolicy);
+  CoreConfiguration::RegisterEphemeralBuilder(
+      [](CoreConfiguration::Builder* builder) {
+        RegisterTestPickArgsLoadBalancingPolicy(
+            builder,
+            [](const PickArgsSeen& pick_args) {
+              GRPC_CHECK_NE(g_pick_args_vector, nullptr);
+              g_pick_args_vector->push_back(pick_args);
+            },
+            kDropPolicyName);
+      });
+  CoreConfiguration::RegisterEphemeralBuilder(RegisterDropPolicy);
   std::vector<PickArgsSeen> pick_args_seen;
   g_pick_args_vector = &pick_args_seen;
-  InitServer(ChannelArgs());
+  InitServer(DefaultServerArgs());
   InitClient(ChannelArgs().Set(
       GRPC_ARG_SERVICE_CONFIG,
       "{\n"
