@@ -14,10 +14,8 @@
 #include <grpc/support/port_platform.h>
 
 #ifdef GPR_WINDOWS
-#include <gmock/gmock.h>
 #include <grpc/grpc.h>
 #include <grpc/support/log_windows.h>
-#include <gtest/gtest.h>
 
 #include <thread>
 #include <variant>
@@ -25,6 +23,8 @@
 #include "absl/log/log.h"
 #include "absl/status/status.h"
 #include "absl/time/time.h"
+#include "gmock/gmock.h"
+#include "gtest/gtest.h"
 #include "src/core/lib/event_engine/common_closures.h"
 #include "src/core/lib/event_engine/poller.h"
 #include "src/core/lib/event_engine/thread_pool/thread_pool.h"
