@@ -16,8 +16,7 @@
 //
 //
 
-#include <gtest/gtest.h>
-
+#include "gtest/gtest.h"
 #include "src/core/lib/address_utils/parse_address.h"
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/lib/iomgr/port.h"
@@ -187,7 +186,7 @@ void test_fails(void) {
         break;
       case GRPC_TIMERS_NOT_CHECKED:
         polling_deadline = grpc_core::Timestamp::ProcessEpoch();
-        ABSL_FALLTHROUGH_INTENDED;
+        [[fallthrough]];
       case GRPC_TIMERS_CHECKED_AND_EMPTY:
         ASSERT_TRUE(GRPC_LOG_IF_ERROR(
             "pollset_work",
@@ -339,7 +338,7 @@ void test_fails_bad_addr_no_leak(void) {
         break;
       case GRPC_TIMERS_NOT_CHECKED:
         polling_deadline = grpc_core::Timestamp::ProcessEpoch();
-        ABSL_FALLTHROUGH_INTENDED;
+        [[fallthrough]];
       case GRPC_TIMERS_CHECKED_AND_EMPTY:
         ASSERT_TRUE(GRPC_LOG_IF_ERROR(
             "pollset_work",
