@@ -14,19 +14,17 @@
 
 #include "src/core/lib/slice/slice_buffer.h"
 
+#include <grpc/slice.h>
+#include <grpc/support/alloc.h>
+#include <grpc/support/port_platform.h>
 #include <string.h>
 
 #include <memory>
 #include <utility>
 
-#include "absl/log/check.h"
 #include "gtest/gtest.h"
-
-#include <grpc/slice.h>
-#include <grpc/support/alloc.h>
-#include <grpc/support/port_platform.h>
-
 #include "src/core/lib/slice/slice.h"
+#include "src/core/util/grpc_check.h"
 
 using ::grpc_core::Slice;
 using ::grpc_core::SliceBuffer;
@@ -34,7 +32,7 @@ using ::grpc_core::SliceBuffer;
 static constexpr int kNewSliceLength = 100;
 
 Slice MakeSlice(size_t len) {
-  CHECK_GT(len, 0);
+  GRPC_CHECK_GT(len, 0);
   unsigned char* contents = static_cast<unsigned char*>(gpr_malloc(len));
   memset(contents, 'a', len);
   return Slice(grpc_slice_new(contents, len, gpr_free));
