@@ -14,7 +14,6 @@
 // limitations under the License.
 //
 
-#include <gmock/gmock.h>
 #include <grpc/credentials.h>
 #include <grpc/grpc.h>
 #include <grpc/support/alloc.h>
@@ -24,7 +23,6 @@
 #include <grpcpp/create_channel.h>
 #include <grpcpp/server.h>
 #include <grpcpp/server_builder.h>
-#include <gtest/gtest.h>
 
 #include <deque>
 #include <memory>
@@ -35,19 +33,20 @@
 #include <thread>
 
 #include "absl/cleanup/cleanup.h"
-#include "absl/log/check.h"
 #include "absl/log/log.h"
 #include "absl/memory/memory.h"
 #include "absl/strings/str_cat.h"
 #include "absl/strings/str_format.h"
 #include "absl/synchronization/notification.h"
 #include "absl/types/span.h"
+#include "gmock/gmock.h"
+#include "gtest/gtest.h"
 #include "src/core/client_channel/backup_poller.h"
 #include "src/core/config/config_vars.h"
+#include "src/core/credentials/transport/fake/fake_credentials.h"
 #include "src/core/lib/address_utils/parse_address.h"
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/lib/iomgr/sockaddr.h"
-#include "src/core/lib/security/credentials/fake/fake_credentials.h"
 #include "src/core/load_balancing/grpclb/grpclb.h"
 #include "src/core/load_balancing/grpclb/grpclb_balancer_addresses.h"
 #include "src/core/resolver/endpoint_addresses.h"
@@ -56,6 +55,7 @@
 #include "src/core/util/crash.h"
 #include "src/core/util/debug_location.h"
 #include "src/core/util/env.h"
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/ref_counted_ptr.h"
 #include "src/core/util/sync.h"
 #include "src/cpp/server/secure_server_credentials.h"
@@ -63,6 +63,7 @@
 #include "src/proto/grpc/testing/echo.grpc.pb.h"
 #include "test/core/test_util/port.h"
 #include "test/core/test_util/resolve_localhost_ip46.h"
+#include "test/core/test_util/test_call_creds.h"
 #include "test/core/test_util/test_config.h"
 #include "test/cpp/end2end/counted_service.h"
 #include "test/cpp/end2end/test_service_impl.h"
@@ -162,13 +163,13 @@ class BackendServiceImpl : public BackendService {
 
 std::string Ip4ToPackedString(const char* ip_str) {
   struct in_addr ip4;
-  CHECK_EQ(inet_pton(AF_INET, ip_str, &ip4), 1);
+  GRPC_CHECK_EQ(inet_pton(AF_INET, ip_str, &ip4), 1);
   return std::string(reinterpret_cast<const char*>(&ip4), sizeof(ip4));
 }
 
 std::string Ip6ToPackedString(const char* ip_str) {
   struct in6_addr ip6;
-  CHECK_EQ(inet_pton(AF_INET6, ip_str, &ip6), 1);
+  GRPC_CHECK_EQ(inet_pton(AF_INET6, ip_str, &ip6), 1);
   return std::string(reinterpret_cast<const char*>(&ip6), sizeof(ip6));
 }
 
@@ -186,8 +187,8 @@ struct ClientStats {
         other.num_calls_finished_with_client_failed_to_send;
     num_calls_finished_known_received +=
         other.num_calls_finished_known_received;
-    for (const auto& p : other.drop_token_counts) {
-      drop_token_counts[p.first] += p.second;
+    for (const auto& [token, count] : other.drop_token_counts) {
+      drop_token_counts[token] += count;
     }
     return *this;
   }
@@ -238,11 +239,11 @@ class BalancerServiceImpl : public BalancerService {
 
   void ShutdownStream() {
     grpc_core::MutexLock lock(&mu_);
-    response_queue_.emplace_back(absl::nullopt);
+    response_queue_.emplace_back(std::nullopt);
     if (response_cond_ != nullptr) response_cond_->SignalAll();
   }
 
-  absl::optional<ClientStats> WaitForLoadReport(absl::Duration timeout) {
+  std::optional<ClientStats> WaitForLoadReport(absl::Duration timeout) {
     grpc_core::MutexLock lock(&load_report_mu_);
     if (load_report_queue_.empty()) {
       grpc_core::CondVar condition;
@@ -251,7 +252,7 @@ class BalancerServiceImpl : public BalancerService {
                                 timeout * grpc_test_slowdown_factor());
       load_report_cond_ = nullptr;
     }
-    if (load_report_queue_.empty()) return absl::nullopt;
+    if (load_report_queue_.empty()) return std::nullopt;
     ClientStats load_report = std::move(load_report_queue_.front());
     load_report_queue_.pop_front();
     return load_report;
@@ -388,7 +389,7 @@ class BalancerServiceImpl : public BalancerService {
   // Helper for request handler thread to get the next response to be
   // sent on the stream.  Returns nullopt when the test has requested
   // stream shutdown.
-  absl::optional<LoadBalanceResponse> GetNextResponse() {
+  std::optional<LoadBalanceResponse> GetNextResponse() {
     grpc_core::MutexLock lock(&mu_);
     if (response_queue_.empty()) {
       grpc_core::CondVar condition;
@@ -417,7 +418,7 @@ class BalancerServiceImpl : public BalancerService {
   grpc_core::Mutex mu_;
   bool shutdown_ ABSL_GUARDED_BY(&mu_) = false;
   std::vector<std::string> service_names_ ABSL_GUARDED_BY(mu_);
-  std::deque<absl::optional<LoadBalanceResponse>> response_queue_
+  std::deque<std::optional<LoadBalanceResponse>> response_queue_
       ABSL_GUARDED_BY(mu_);
   grpc_core::CondVar* response_cond_ ABSL_GUARDED_BY(mu_) = nullptr;
 
@@ -450,7 +451,7 @@ class GrpclbEnd2endTest : public ::testing::Test {
 
     void Start() {
       LOG(INFO) << "starting " << type_ << " server on port " << port_;
-      CHECK(!running_);
+      GRPC_CHECK(!running_);
       running_ = true;
       service_.Start();
       grpc_core::Mutex mu;
@@ -618,7 +619,7 @@ class GrpclbEnd2endTest : public ::testing::Test {
     for (auto& backend : backends_) backend->service().ResetCounters();
   }
 
-  absl::optional<ClientStats> WaitForLoadReports(
+  std::optional<ClientStats> WaitForLoadReports(
       absl::Duration timeout = absl::Seconds(5)) {
     return balancer_->service().WaitForLoadReport(timeout);
   }
@@ -692,7 +693,7 @@ class GrpclbEnd2endTest : public ::testing::Test {
               << options.num_requests_multiple_of << ") against the backends. "
               << num_ok << " succeeded, " << num_failure << " failed, "
               << num_drops << " dropped.";
-    return std::make_tuple(num_ok, num_failure, num_drops);
+    return std::tuple(num_ok, num_failure, num_drops);
   }
 
   void WaitForBackend(size_t backend_idx,
@@ -707,9 +708,9 @@ class GrpclbEnd2endTest : public ::testing::Test {
     for (int port : ports) {
       absl::StatusOr<grpc_core::URI> lb_uri =
           grpc_core::URI::Parse(grpc_core::LocalIpUri(port));
-      CHECK_OK(lb_uri);
+      GRPC_CHECK_OK(lb_uri);
       grpc_resolved_address address;
-      CHECK(grpc_parse_uri(*lb_uri, &address));
+      GRPC_CHECK(grpc_parse_uri(*lb_uri, &address));
       grpc_core::ChannelArgs args;
       if (!balancer_name.empty()) {
         args = args.Set(GRPC_ARG_DEFAULT_AUTHORITY, balancer_name);
@@ -728,7 +729,7 @@ class GrpclbEnd2endTest : public ::testing::Test {
     result.addresses = std::move(backends);
     result.service_config = grpc_core::ServiceConfigImpl::Create(
         grpc_core::ChannelArgs(), service_config_json);
-    CHECK_OK(result.service_config);
+    GRPC_CHECK_OK(result.service_config);
     result.args = grpc_core::SetGrpcLbBalancerAddresses(
         grpc_core::ChannelArgs(), std::move(balancers));
     response_generator_->SetResponseSynchronously(std::move(result));
@@ -766,11 +767,11 @@ class GrpclbEnd2endTest : public ::testing::Test {
       const std::vector<int>& backend_ports,
       const std::map<std::string, size_t>& drop_token_counts) {
     LoadBalanceResponse response;
-    for (const auto& drop_token_count : drop_token_counts) {
-      for (size_t i = 0; i < drop_token_count.second; ++i) {
+    for (const auto& [token, count] : drop_token_counts) {
+      for (size_t i = 0; i < count; ++i) {
         auto* server = response.mutable_server_list()->add_servers();
         server->set_drop(true);
-        server->set_load_balance_token(drop_token_count.first);
+        server->set_load_balance_token(token);
       }
     }
     for (const int& backend_port : backend_ports) {
