@@ -12,36 +12,34 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+#include <grpc/support/port_platform.h>
 #include <signal.h>
 #include <string.h>
 
-#include <grpc/support/port_platform.h>
-
 #ifndef GPR_WINDOWS
 #include <unistd.h>
 #endif  // GPR_WINDOWS
 
+#include <grpc/grpc.h>
+#include <grpc/support/alloc.h>
+#include <grpc/support/string_util.h>
+
 #include <memory>
 #include <string>
 #include <thread>
 #include <vector>
 
 #include "absl/flags/flag.h"
-#include "absl/log/check.h"
 #include "absl/log/log.h"
 #include "absl/strings/str_format.h"
-
-#include <grpc/grpc.h>
-#include <grpc/support/alloc.h>
-#include <grpc/support/string_util.h>
-
-#include "src/core/lib/gprpp/crash.h"
+#include "src/core/util/crash.h"
+#include "src/core/util/grpc_check.h"
 
 #ifdef __FreeBSD__
 #include <sys/wait.h>
 #endif
 
-#include "src/core/lib/gprpp/env.h"
+#include "src/core/util/env.h"
 #include "test/core/test_util/port.h"
 #include "test/core/test_util/test_config.h"
 #include "test/cpp/util/subprocess.h"
@@ -100,12 +98,12 @@ int main(int argc, char** argv) {
   grpc::testing::TestEnvironment env(&argc, argv);
   grpc::testing::InitTest(&argc, &argv, true);
   grpc_init();
-  CHECK(!absl::GetFlag(FLAGS_test_bin_name).empty());
+  GRPC_CHECK(!absl::GetFlag(FLAGS_test_bin_name).empty());
   std::string my_bin = argv[0];
   int result = 0;
   if (absl::GetFlag(FLAGS_running_under_bazel)) {
-    CHECK(!absl::GetFlag(FLAGS_grpc_test_directory_relative_to_test_srcdir)
-               .empty());
+    GRPC_CHECK(!absl::GetFlag(FLAGS_grpc_test_directory_relative_to_test_srcdir)
+                    .empty());
     // Use bazel's TEST_SRCDIR environment variable to locate the "test data"
     // binaries.
     auto test_srcdir = grpc_core::GetEnv("TEST_SRCDIR");
@@ -114,7 +112,7 @@ int main(int argc, char** argv) {
         test_srcdir.value() +
         absl::GetFlag(FLAGS_grpc_test_directory_relative_to_test_srcdir) +
         std::string("/test/cpp/naming");
-    // Invoke bazel's executeable links to the .sh and .py scripts (don't use
+    // Invoke bazel's executable links to the .sh and .py scripts (don't use
     // the .sh and .py suffixes) to make
     // sure that we're using bazel's test environment.
     result = grpc::testing::InvokeResolverComponentTestsRunner(
@@ -170,5 +168,19 @@ int main(int argc, char** argv) {
         "test/cpp/naming/utils/tcp_connect.py");
   }
   grpc_shutdown();
+#ifndef GPR_WINDOWS
+  if (WIFEXITED(result)) {
+    if (WEXITSTATUS(result) != 0) {
+      int error_code = WEXITSTATUS(result);
+      LOG(FATAL) << "DNS test subprocess failed with code: " << error_code;
+    }
+  } else if (WIFSIGNALED(result)) {
+    int signal = WTERMSIG(result);
+    LOG(FATAL) << "DNS test subprocess killed by signal: " << signal;
+  } else {
+    LOG(FATAL) << "DNS test subprocess failed, neither WEXITSTATUS nor "
+                  "WTERMSIG is true";
+  }
+#endif
   return result;
 }
