@@ -140,6 +140,9 @@ LANG_RELEASE_MATRIX = {
             ("v1.69.0", ReleaseInfo()),
             ("v1.70.0", ReleaseInfo()),
             ("v1.71.0", ReleaseInfo()),
+            ("v1.72.0", ReleaseInfo()),
+            ("v1.73.0", ReleaseInfo()),
+            ("v1.74.0", ReleaseInfo()),
         ]
     ),
     "go": OrderedDict(
@@ -314,7 +317,11 @@ LANG_RELEASE_MATRIX = {
             ("v1.68.2", ReleaseInfo()),
             ("v1.69.4", ReleaseInfo()),
             ("v1.70.0", ReleaseInfo()),
-            ("v1.71.0", ReleaseInfo()),
+            ("v1.71.3", ReleaseInfo()),
+            ("v1.72.3", ReleaseInfo()),
+            ("v1.73.1", ReleaseInfo()),
+            ("v1.74.3", ReleaseInfo()),
+            ("v1.75.1", ReleaseInfo()),
         ]
     ),
     "java": OrderedDict(
@@ -464,6 +471,9 @@ LANG_RELEASE_MATRIX = {
             ("v1.68.3", ReleaseInfo()),
             ("v1.69.1", ReleaseInfo()),
             ("v1.70.0", ReleaseInfo()),
+            ("v1.71.0", ReleaseInfo()),
+            ("v1.72.0", ReleaseInfo()),
+            ("v1.73.0", ReleaseInfo()),
         ]
     ),
     "python": OrderedDict(
@@ -852,6 +862,24 @@ LANG_RELEASE_MATRIX = {
                     runtimes=["python"], testcases_file="python__master"
                 ),
             ),
+            (
+                "v1.72.0",
+                ReleaseInfo(
+                    runtimes=["python"], testcases_file="python__master"
+                ),
+            ),
+            (
+                "v1.73.0",
+                ReleaseInfo(
+                    runtimes=["python"], testcases_file="python__master"
+                ),
+            ),
+            (
+                "v1.74.0",
+                ReleaseInfo(
+                    runtimes=["python"], testcases_file="python__master"
+                ),
+            ),
         ]
     ),
     "node": OrderedDict(
@@ -956,6 +984,9 @@ LANG_RELEASE_MATRIX = {
             ("v1.69.0", ReleaseInfo()),
             ("v1.70.0", ReleaseInfo()),
             ("v1.71.0", ReleaseInfo()),
+            ("v1.72.0", ReleaseInfo()),
+            ("v1.73.0", ReleaseInfo()),
+            ("v1.74.0", ReleaseInfo()),
         ]
     ),
     "php": OrderedDict(
@@ -1023,6 +1054,9 @@ LANG_RELEASE_MATRIX = {
             ("v1.67.0", ReleaseInfo()),
             ("v1.70.0", ReleaseInfo()),
             ("v1.71.0", ReleaseInfo()),
+            ("v1.72.0", ReleaseInfo()),
+            ("v1.73.0", ReleaseInfo()),
+            ("v1.74.0", ReleaseInfo()),
         ]
     ),
     "csharp": OrderedDict(
